@@ -1,4 +1,12 @@
-''' simple dlpoly utilities to play with inputs and outputs '''
+"""Simple DL_POLY_4 utilities to play with inputs and outputs.
+
+typical usage
+
+>>>   from dlpoly import DLPoly
+>>>   dlPoly = DLPoly(control="Ar.control", config="Ar.config",
+>>>                   field="Ar.field", workdir="argon")
+
+"""
 
 from distutils.version import LooseVersion
 from os.path import dirname, basename, isfile, join
@@ -19,7 +27,7 @@ modules = glob.glob(join(dirname(__file__), "*.py"))
 __all__ = [basename(f)[:-3] for f in modules if isfile(f)
            and not f.endswith('__init__.py')]
 
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 
 try:
     from .dlpoly import DLPoly
